@@ -1,10 +1,9 @@
 package Plack::App::FakeApache1::Request;
-{
-  $Plack::App::FakeApache1::Request::VERSION = '0.0.4';
-}
 {
   $Plack::App::FakeApache1::Request::DIST = 'Plack-App-FakeApache1';
 }
+$Plack::App::FakeApache1::Request::VERSION = '0.0.5';
+# ABSTRACT: Mimic Apache1 requests
 use Moose;
 
 use HTTP::Status qw(:is :constants);
@@ -96,7 +95,7 @@ sub _build__subprocess_env { return Moose::APR::Table->new; }
 sub _build_dispatcher      { return Plack::App::FakeModPerl1::Dispatcher->new; }
 
 # Plack methods
-sub finalize { 
+sub finalize {
     my $self     = shift;
     my $response = $self->plack_response;
 
@@ -148,12 +147,10 @@ __PACKAGE__->meta->make_immutable;
 
 
 package Moose::APR::Table;
-{
-  $Moose::APR::Table::VERSION = '0.0.4';
-}
 {
   $Moose::APR::Table::DIST = 'Plack-App-FakeApache1';
 }
+$Moose::APR::Table::VERSION = '0.0.5';
 use Moose;
 no Moose;
 
@@ -172,11 +169,19 @@ __END__
 
 =head1 NAME
 
-Plack::App::FakeApache1::Request
+Plack::App::FakeApache1::Request - Mimic Apache1 requests
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
+
+=head2 finalize
+
+=head2 subprocess_env
+
+=head2 print
+
+=head2 rflush
 
 =head1 AUTHOR
 
@@ -184,7 +189,7 @@ Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chisel Wright.
+This software is copyright (c) 2014 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
