@@ -1,10 +1,9 @@
 package Plack::App::FakeModPerl1;
-{
-  $Plack::App::FakeModPerl1::VERSION = '0.0.4';
-}
 {
   $Plack::App::FakeModPerl1::DIST = 'Plack-App-FakeApache1';
 }
+$Plack::App::FakeModPerl1::VERSION = '0.0.5';
+# ABSTRACT: Mimic Apache's mod_perl1
 use 5.10.1;
 use Moose;
 
@@ -15,6 +14,7 @@ use Package::DeprecationManager -deprecations => {
     'Plack::App::FakeModPerl1::send_http_header'    => '0.0.1',
 };
 
+
 use Plack::App::FakeModPerl1::Dispatcher;
 use Plack::App::FakeModPerl1::Server;
 use Plack::Util;
@@ -163,21 +163,69 @@ __END__
 
 =head1 NAME
 
-Plack::App::FakeModPerl1
+Plack::App::FakeModPerl1 - Mimic Apache's mod_perl1
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
+
+BORROWED HEAVILY FROM
 
 L<https://github.com/pdonelan/webgui/blob/plebgui/lib/WebGUI/Session/Plack.pm>
 
+=head2 handle_psgi
+
+=head2 new
+
+=head2 uri
+
+=head2 param
+
+=head2 params
+
+=head2 headers_in
+
+=head2 headers_out
+
+=head2 protocol
+
+=head2 pnotes
+
+=head2 status
+
+=head2 sendfile
+
+=head2 server
+
+=head2 method
+
+=head2 upload
+
+=head2 dir_config
+
+=head2 status_line
+
+=head2 auth_type
+
+=head2 handler
+
+=head2 send_http_header
+
+=head2 parsed_uri
+
+=head2 content_type
+
+=head2 print
+
+=head2 finalize
+
 =head1 AUTHOR
 
 Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chisel Wright.
+This software is copyright (c) 2014 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
