@@ -1,10 +1,9 @@
 package Plack::App::FakeModPerl1::Dispatcher;
-{
-  $Plack::App::FakeModPerl1::Dispatcher::VERSION = '0.0.4';
-}
 {
   $Plack::App::FakeModPerl1::Dispatcher::DIST = 'Plack-App-FakeApache1';
 }
+$Plack::App::FakeModPerl1::Dispatcher::VERSION = '0.0.5';
+# ABSTRACT: Mimic Apache mod_perl1's dispatcher
 use 5.10.1;
 use Moose;
 
@@ -57,6 +56,7 @@ sub _build_parsed_apache_config {
 }
 
 
+
 sub dispatch_for {
     my $self    = shift;
     my $plack   = shift;
@@ -204,7 +204,7 @@ sub _call_handler {
         }
     }
     catch ($e) {
-        Carp::cluck( "$module->handler(): $e" );
+        Carp::confess( "$module->handler(): $e" );
         # if we error we override the status of everything up to this point!
         return HTTP_INTERNAL_SERVER_ERROR;
     }
@@ -266,11 +266,11 @@ __END__
 
 =head1 NAME
 
-Plack::App::FakeModPerl1::Dispatcher
+Plack::App::FakeModPerl1::Dispatcher - Mimic Apache mod_perl1's dispatcher
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =begin explanation
 
@@ -287,18 +287,20 @@ characters)
 Looking at:
 http://ertw.com/blog/2007/08/23/apache-and-overlapping-location-directives/
 
-So the general plan of action iis to process each match in order, and store
+So the general plan of action is to process each match in order, and store
 any new settings, potentially overriding existing ones.
-This appears to be how apache does it, and hasn't broken in any obvious ways
+This appears to be how Apache does it, and hasn't broken in any obvious ways
 yet.
 
+=head2 dispatch_for
+
 =head1 AUTHOR
 
 Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chisel Wright.
+This software is copyright (c) 2014 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
