@@ -1,10 +1,9 @@
 package Plack::App::FakeModPerl1::Server;
-{
-  $Plack::App::FakeModPerl1::Server::VERSION = '0.0.4';
-}
 {
   $Plack::App::FakeModPerl1::Server::DIST = 'Plack-App-FakeApache1';
 }
+$Plack::App::FakeModPerl1::Server::VERSION = '0.0.5';
+# ABSTRACT: Mimic Apache mod_perl1's server
 use strict;
 use warnings;
 use 5.10.1;
@@ -44,11 +43,15 @@ __END__
 
 =head1 NAME
 
-Plack::App::FakeModPerl1::Server
+Plack::App::FakeModPerl1::Server - Mimic Apache mod_perl1's server
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
+
+=head2 new
+
+=head2 dir_config
 
 =head1 AUTHOR
 
@@ -56,7 +59,7 @@ Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chisel Wright.
+This software is copyright (c) 2014 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
